<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About CoolReader</source>
        <translation>O programu Cool Reader</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <source>Cool Reader 3.0.22</source>
        <translation type="obsolete">Cool Reader 3.0.22</translation>
    </message>
    <message>
        <source>(c) 1998-2009 Vadim Lopatin</source>
        <translation type="obsolete">(c) 1998-2009 Vadim Lopatin</translation>
    </message>
    <message>
        <source>About Cool Reader</source>
        <translation>O programu CoolReader</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;CoolReader is free open source e-book viewer based on CoolReader engine.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Source code is avaliable at SourceForge &lt;/span&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;http://sourceforge.net/projects/crengine &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;under the terms of GNU GPL2 license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;Third party components used:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Qt %QT_VER% - as GUI library&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;FreeType - font engine&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;ZLib - compressing library&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libpng - PNG image format support&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libjpeg - JPEG image format support&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Hyphenation dictionaries - from AlReader&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;CoolReader je svobodný prohlížeč elektronických knih s otevřeným zdrojovým kódem založený na stroji CoolReader.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Zdrojový kód je dostupný na SourceForge &lt;/span&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;http://sourceforge.net/projects/crengine &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;za podmínek licence GNU GPL2.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;Použité součásti od třetích stran:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Qt %QT_VER% - jako knihovna GUI&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;FreeType - písmo&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;ZLib - kompresní knihovna&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libpng - podpora pro obrázkový formát PNG&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libjpeg - podpora pro obrázkový formát JPEG&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Slovníky na dělení slov - z AlReader&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Povolení</translation>
    </message>
    <message>
        <source>Source code may be downloaded from sourceforge crengine project page.

Latest source code is available from CVS:
cvs -z3 -d:pserver:anonymous@crengine.cvs.sourceforge.net:/cvsroot/crengine co -P cr3qt
cd cr3qt
cvs -z3 -d:pserver:anonymous@crengine.cvs.sourceforge.net:/cvsroot/crengine co -P crengine
cvs -z3 -d:pserver:anonymous@crengine.cvs.sourceforge.net:/cvsroot/tinydict co -P tinydict</source>
        <translation type="obsolete">Zdrojový kód lze stáhnout ze stránek projektu crengine na sourceforge.

Nejnovější zdrojový kód je dostupný z CVS:
cvs -z3 -d:pserver:anonymous@crengine.cvs.sourceforge.net:/cvsroot/crengine co -P cr3qt
cd cr3qt
cvs -z3 -d:pserver:anonymous@crengine.cvs.sourceforge.net:/cvsroot/crengine co -P crengine
cvs -z3 -d:pserver:anonymous@crengine.cvs.sourceforge.net:/cvsroot/tinydict co -P tinydict</translation>
    </message>
    <message>
        <source>Source Code</source>
        <translation>Zdrojový kód</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;CoolReader is free open source e-book viewer based on CoolReader engine.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Source code is available at SourceForge &lt;/span&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;http://sourceforge.net/projects/crengine &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;under the terms of GNU GPL2 license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;Third party components used:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Qt %QT_VER% - as GUI library&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;FreeType - font engine&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;ZLib - compressing library&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libpng - PNG image format support&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libjpeg - JPEG image format support&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Hyphenation dictionaries - from AlReader&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;CoolReader je svobodný prohlížeč elektronických knih s otevřeným zdrojovým kódem založený na stroji CoolReader.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Zdrojový kód je dostupný na SourceForge &lt;/span&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;http://sourceforge.net/projects/crengine &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;za podmínek licence GNU GPL2.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;Použité součásti od třetích stran:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Qt %QT_VER% - jako knihovna GUI&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;FreeType - písmo&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;ZLib - kompresní knihovna&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libpng - podpora pro obrázkový formát PNG&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libjpeg - podpora pro obrázkový formát JPEG&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Slovníky na dělení slov - z AlReader&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Source code may be downloaded from sourceforge crengine project page:
http://sourceforge.net/projects/crengine/

Latest source code is available from GIT repository:
&gt; git clone git://crengine.git.sourceforge.net/gitroot/crengine/crengine

See README.TXT at root directory of project for build instructions.
</source>
        <translation>Zdrojový kód lze stáhnout ze stránek projektu crengine na sourceforge.

Nejnovější zdrojový kód je dostupný z úložiště GIT:
&gt; git clone git://crengine.git.sourceforge.net/gitroot/crengine/crengine

Podívejte se v souboru README.TXT v kořenovém adresáři na pokyn pro sestavení.
</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;CoolReader is free open source e-book viewer based on CoolReader engine.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Source code is available at SourceForge &lt;/span&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;http://sourceforge.net/projects/crengine &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;under the terms of GNU GPL2 license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;Third party components used:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Qt %QT_VER% - as GUI library&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;FreeType - font engine&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;HarfBuzz - font kerning&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;ZLib - compressing library&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libpng - PNG image format support&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libjpeg - JPEG image format support&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Hyphenation dictionaries - from AlReader&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;CoolReader je svobodný prohlížeč elektronických knih s otevřeným zdrojovým kódem založený na stroji CoolReader.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Zdrojový kód je dostupný na SourceForge &lt;/span&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;http://sourceforge.net/projects/crengine &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;za podmínek licence GNU GPL2.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;Použité součásti od třetích stran:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Qt %QT_VER% - jako knihovna GUI&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;FreeType - písmo&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;HarfBuzz - kerning písma&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;ZLib - kompresní knihovna&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libpng - podpora pro obrázkový formát PNG&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libjpeg - podpora pro obrázkový formát JPEG&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Slovníky na dělení slov - z AlReader&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add bookmark</source>
        <translation>Přídat záložku</translation>
    </message>
    <message>
        <source>Correction</source>
        <translation>Oprava</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Bookmark type</source>
        <translation>Typ záložky</translation>
    </message>
    <message>
        <source>Page 1/10 10%</source>
        <translation>Strana 1/10 10%</translation>
    </message>
    <message>
        <source>Position text</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>sample title</source>
        <translation>Název vzorku</translation>
    </message>
</context>
<context>
    <name>BookmarkListDialog</name>
    <message>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <source>Type</source>
        <comment>bookmark type</comment>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>P</source>
        <comment>Bookmark type first letter - Position</comment>
        <translation>P</translation>
    </message>
    <message>
        <source>C</source>
        <comment>Bookmark type first letter - Comment</comment>
        <translation>C</translation>
    </message>
    <message>
        <source>E</source>
        <comment>Bookmark type first letter - Correction/Edit</comment>
        <translation>E</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Go to Bookmark</source>
        <translation>Jít na záložku</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Odstranit záložku</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Remove ALL Bookmarks</source>
        <translation>Odstranit všechny záložky</translation>
    </message>
    <message>
        <source>Edit Bookmark</source>
        <translation>Upravit záložku</translation>
    </message>
    <message>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
</context>
<context>
    <name>CR3View</name>
    <message>
        <source>Error while opening document </source>
        <translation>Chyba při otevírání dokumentu</translation>
    </message>
    <message>
        <source>Loading: please wait...</source>
        <translation>Nahrává se: Počkejte, prosím...</translation>
    </message>
</context>
<context>
    <name>ExportProgressDlg</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Export is in progress...</source>
        <translation>Probíhá vyvádění...</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <source>Document properties</source>
        <translation>Vlastnosti dokumentu</translation>
    </message>
    <message>
        <source>Property</source>
        <translation>Vlastnost</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Hodnota</translation>
    </message>
    <message>
        <source>Current page</source>
        <translation>Nynější strana</translation>
    </message>
    <message>
        <source>Total pages</source>
        <translation>Stran celkem</translation>
    </message>
    <message>
        <source>Battery state</source>
        <translation>Stav baterie</translation>
    </message>
    <message>
        <source>Current Time</source>
        <translation>Nynější čas</translation>
    </message>
    <message>
        <source>Current chapter</source>
        <translation>Nynější kapitola</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Archive name</source>
        <translation>Název archivu</translation>
    </message>
    <message>
        <source>Archive path</source>
        <translation>Cesta k archivu</translation>
    </message>
    <message>
        <source>Archive size</source>
        <translation>Velikost archivu</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <source>File path</source>
        <translation>Cesta k souboru</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <source>File format</source>
        <translation>Formát souboru</translation>
    </message>
    <message>
        <source>File info</source>
        <translation>Informace o souboru</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Author(s)</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Series name</source>
        <translation>Název řady</translation>
    </message>
    <message>
        <source>Series number</source>
        <translation>Číslo v řadě</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Genres</source>
        <translation>Žánry</translation>
    </message>
    <message>
        <source>Translator</source>
        <translation>Překladatel</translation>
    </message>
    <message>
        <source>Book info</source>
        <translation>Informace o knize</translation>
    </message>
    <message>
        <source>Document author</source>
        <translation>Autor dokumentu</translation>
    </message>
    <message>
        <source>Document date</source>
        <translation>Čas vytvoření dokumentu</translation>
    </message>
    <message>
        <source>Document source URL</source>
        <translation>Adresa zdroje dokumentu (URL)</translation>
    </message>
    <message>
        <source>OCR by</source>
        <translation>Optické rozpoznání znaků</translation>
    </message>
    <message>
        <source>Document version</source>
        <translation>Verze dokumentu</translation>
    </message>
    <message>
        <source>Document info</source>
        <translation>Informace o dokumentu</translation>
    </message>
    <message>
        <source>Publication name</source>
        <translation>Název vydání</translation>
    </message>
    <message>
        <source>Publisher</source>
        <translation>Vydavatel</translation>
    </message>
    <message>
        <source>Publisher city</source>
        <translation>Město vydavatele</translation>
    </message>
    <message>
        <source>Publication year</source>
        <translation>Rok vydání</translation>
    </message>
    <message>
        <source>ISBN</source>
        <translation>ISBN</translation>
    </message>
    <message>
        <source>Publication info</source>
        <translation>Informace o vydání</translation>
    </message>
    <message>
        <source>Custom info</source>
        <translation>Vlastní informace</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Open book file</source>
        <translation>Otevřít soubor s knihou</translation>
    </message>
    <message>
        <source>All supported formats (*.fb2 *.txt *.tcr *.rtf *.epub *.html *.htm *.zip);;FB2 books (*.fb2 *.fb2.zip);;Text files (*.txt);;Rich text (*.rtf);;HTML files (*.htm *.html);;EPUB files (*.epub);;ZIP archives (*.zip)</source>
        <translation type="obsolete">Všechny podporované formáty (*.fb2 *.txt *.tcr *.rtf *.epub *.html *.htm *.zip);;Knihy FB2 (*.fb2 *.fb2.zip);;Textové soubory (*.txt);;Bohatý text (*.rtf);;HTML files (*.htm *.html);;Soubory EPUB (*.epub);;ZIP archivy (*.zip)</translation>
    </message>
    <message>
        <source>Not implemented</source>
        <translation type="obsolete">Neprovedeno</translation>
    </message>
    <message>
        <source>Search is not implemented yet</source>
        <translation type="obsolete">Hledání není uděláno</translation>
    </message>
    <message>
        <source>Export document to</source>
        <translation>Vyvést dokument do</translation>
    </message>
    <message>
        <source>WOL book (*.wol)</source>
        <translation>Kniha WOL (*.wol)</translation>
    </message>
    <message>
        <source>Export to WOL format</source>
        <translation>Vyvést do formátu WOL</translation>
    </message>
    <message>
        <source>All supported formats</source>
        <translation>Všechny podporované formáty</translation>
    </message>
    <message>
        <source>FB2 books</source>
        <translation>Knihy FB2</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation>Textové soubory</translation>
    </message>
    <message>
        <source>Rich text</source>
        <translation>Bohatý text</translation>
    </message>
    <message>
        <source>MS Word document</source>
        <translation>Dokument MS Word</translation>
    </message>
    <message>
        <source>HTML files</source>
        <translation>Soubory HTML</translation>
    </message>
    <message>
        <source>EPUB files</source>
        <translation>Soubory EPUB</translation>
    </message>
    <message>
        <source>CHM files</source>
        <translation>Soubory CHM</translation>
    </message>
    <message>
        <source>MOBI files</source>
        <translation>Soubory MOBI</translation>
    </message>
    <message>
        <source>PalmDOC files</source>
        <translation>Soubory PalmDOC</translation>
    </message>
    <message>
        <source>ZIP archives</source>
        <translation>Archivy ZIP</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <source>CoolReader</source>
        <translation>CoolReader</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Otevřít...</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>Toggle Pages/Scroll</source>
        <translation>Přepnout dvě strany/svitek</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>F12</source>
        <translation>F12</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Zmenšit</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Page Down</source>
        <translation>O stranu dolů</translation>
    </message>
    <message>
        <source>Go to next page</source>
        <translation>Jít na další stranu</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Page Up</source>
        <translation>O stranu nahoru</translation>
    </message>
    <message>
        <source>Back by page</source>
        <translation>O stranu zpět</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Line Down</source>
        <translation>O jeden řádek dolů</translation>
    </message>
    <message>
        <source>Forward by one line</source>
        <translation>O jeden řádek dopředu</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Šipka dolů</translation>
    </message>
    <message>
        <source>Line Up</source>
        <translation>O jeden řádek nahoru</translation>
    </message>
    <message>
        <source>Back by line</source>
        <translation>O řádek zpět</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Šipka nahoru</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>První strana</translation>
    </message>
    <message>
        <source>Go to first page</source>
        <translation>Jít na první stranu</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>Poslední strana</translation>
    </message>
    <message>
        <source>Go to last page</source>
        <translation>Jít na poslední stranu</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Back in navigation history</source>
        <translation>Zpět v historii pohybu</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vpřed</translation>
    </message>
    <message>
        <source>Go to the next position in navigation history</source>
        <translation>Jít na další místo v historii pohybu</translation>
    </message>
    <message>
        <source>Shift+Backspace</source>
        <translation>Shift+Backspace</translation>
    </message>
    <message>
        <source>Next Chapter</source>
        <translation>Další kapitola</translation>
    </message>
    <message>
        <source>Go to next chapter</source>
        <translation>Jít na další kapitolu</translation>
    </message>
    <message>
        <source>Alt+Down</source>
        <translation>Alt+Down</translation>
    </message>
    <message>
        <source>Previous Chapter</source>
        <translation>Předchozí kapitola</translation>
    </message>
    <message>
        <source>Go to previous chapter</source>
        <translation>Jít na předchozí kapitolu</translation>
    </message>
    <message>
        <source>Alt+Up</source>
        <translation>Alt+Up</translation>
    </message>
    <message>
        <source>Toggle Full Screen</source>
        <translation>Přepnout na celou obrazovku</translation>
    </message>
    <message>
        <source>Toggle Full Screen mode</source>
        <translation>Režim přepnutí na celou obrazovku</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>ALT+Return</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Přiblížit</translation>
    </message>
    <message>
        <source>Increase font size</source>
        <translation>Zvětšit velikost písma</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Oddálit</translation>
    </message>
    <message>
        <source>Decrease font size</source>
        <translation>Zmenšit velikost písma</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Table of Contents...</source>
        <translation>Obsah...</translation>
    </message>
    <message>
        <source>Show table of contents</source>
        <translation>Ukázat obsah</translation>
    </message>
    <message>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <source>Recent Books</source>
        <translation>Naposledy otevřené knihy</translation>
    </message>
    <message>
        <source>Show recent books list</source>
        <translation>Ukázat seznam naposledy otevřených knih</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation>Nastavení...</translation>
    </message>
    <message>
        <source>Settings dialog</source>
        <translation>Dialog pro nastavení</translation>
    </message>
    <message>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Copy selected text</source>
        <translation>Kopírovat vybraný text</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>copy2</source>
        <translation>Kopie2</translation>
    </message>
    <message>
        <source>Copy alternative shortcut</source>
        <translation>Kopírovat náhradní zkratku</translation>
    </message>
    <message>
        <source>Ctrl+Ins</source>
        <translation>Ctrl+Ins</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <source>About CoolReader</source>
        <translation>O programu CoolReader</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Přidat záložku</translation>
    </message>
    <message>
        <source>Add bookmark</source>
        <translation>Přídat záložku</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Bookmark List...</source>
        <translation>Seznam záložek...</translation>
    </message>
    <message>
        <source>Show bookmarks list</source>
        <translation>Ukázat seznam záložek</translation>
    </message>
    <message>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <source>File Properties...</source>
        <translation>Vlastnosti souboru...</translation>
    </message>
    <message>
        <source>Show file properties</source>
        <translation>Ukázat vlastnosti souboru</translation>
    </message>
    <message>
        <source>Ctrl+F1</source>
        <translation>Ctrl+F1</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Otočit</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Find text...</source>
        <translation>Hledat text...</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Hledat text</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Toggle Edit Mode</source>
        <translation>Přepnout režim úprav</translation>
    </message>
    <message>
        <source>Toggle edit mode</source>
        <translation>Přepnout režim úprav</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Pohyb</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vyvést</translation>
    </message>
    <message>
        <source>Export document</source>
        <translation>Vyvést dokument</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Další strana</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Šipka vpravo</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Předchozí strana</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Šipka vlevo</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Mezerník</translation>
    </message>
    <message>
        <source>Next Sentence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move selection to next sentence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>actionPrevSentence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select orevious sentence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Left</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentBooksDlg</name>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <source>Remove all history items</source>
        <translation>Odstranit všechny položky historie</translation>
    </message>
    <message>
        <source>Do you really want to remove all history records?</source>
        <translation>Opravdu chcete odstranit všechnyzáznamy o minulosti?</translation>
    </message>
    <message>
        <source>Recent Books</source>
        <translation>Naposledy otevřené knihy</translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Odstranit položku</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Smazat vše</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Not found</source>
        <translation>Nenalezeno</translation>
    </message>
    <message>
        <source>Search pattern is not found in document</source>
        <translation>Hledaný vzor nebyl v dokumentu nalezen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledání</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Rozlišovat velká a malá písmena</translation>
    </message>
    <message>
        <source>Search forward</source>
        <translation>Hledat dopředu</translation>
    </message>
    <message>
        <source>Search backward</source>
        <translation>Hledat dozadu</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Najít další</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>SettingsDlg</name>
    <message>
        <source>[No hyphenation]</source>
        <translation>[Žádné dělení slov]</translation>
    </message>
    <message>
        <source>[Algorythmic hyphenation]</source>
        <translation>[Algoritmické dělení slov]</translation>
    </message>
    <message>
        <source>The quick brown fox jumps over the lazy dog. </source>
        <translation>Rychlá bílá liška hbitě skáče přes pomalého ježka. Ó, ú, á, é (zní obdivné výkřiky přihlížejících). </translation>
    </message>
    <message>
        <source>Text color</source>
        <translation>Barva textu</translation>
    </message>
    <message>
        <source>Background color</source>
        <translation>Barva pozadí</translation>
    </message>
    <message>
        <source>Page header text color</source>
        <translation>Barva textu záhlaví strany</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Window options</source>
        <translation>Volby pro okna</translation>
    </message>
    <message>
        <source>Look &amp; feel</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Startup action</source>
        <translation>Při spuštění</translation>
    </message>
    <message>
        <source>Open recent book</source>
        <translation>Otevřít poslední knihu</translation>
    </message>
    <message>
        <source>Show list of recent books</source>
        <translation>Ukázat seznam naposledy otevřených knih</translation>
    </message>
    <message>
        <source>Show File Open dialog</source>
        <translation>Ukázat dialog pro otevření souboru</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Nedělat nic</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Ovládání</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Ukázat nástrojový pruh</translation>
    </message>
    <message>
        <source>Show menu</source>
        <translation>Ukázat nabídku</translation>
    </message>
    <message>
        <source>Show scroll bar</source>
        <translation>Ukázat posuvník</translation>
    </message>
    <message>
        <source>Show status bar</source>
        <translation>Ukázat stavový řádek</translation>
    </message>
    <message>
        <source>Fullscreen display</source>
        <translation>Zobrazení na celou obrazovku</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>One page</source>
        <translation>Jedna strana</translation>
    </message>
    <message>
        <source>Two pages</source>
        <translation>Dvě strany</translation>
    </message>
    <message>
        <source>Scroll View</source>
        <translation>Pohled na svitek</translation>
    </message>
    <message>
        <source>Vew Mode</source>
        <translation>Režim zobrazení</translation>
    </message>
    <message>
        <source>Page margins</source>
        <translation>Okraje stran</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <source>20</source>
        <translation>20</translation>
    </message>
    <message>
        <source>25</source>
        <translation>25</translation>
    </message>
    <message>
        <source>30</source>
        <translation>30</translation>
    </message>
    <message>
        <source>Show page header</source>
        <translation>Ukázat záhlaví strany</translation>
    </message>
    <message>
        <source>Book name</source>
        <translation>Název knihy</translation>
    </message>
    <message>
        <source>Clock</source>
        <translation>Ukazatel času</translation>
    </message>
    <message>
        <source>Battery status</source>
        <translation>Stav baterie</translation>
    </message>
    <message>
        <source>Header font</source>
        <translation>Písmo záhlaví</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Změnit</translation>
    </message>
    <message>
        <source>Show footnotes at bottom of page</source>
        <translation>Ukázat poznámky pod čarou při spodním okraji strany</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Strana</translation>
    </message>
    <message>
        <source>Text font</source>
        <translation>Písmo textu</translation>
    </message>
    <message>
        <source>Hyphenation</source>
        <translation>Dělení slov</translation>
    </message>
    <message>
        <source>Interline spacing</source>
        <translation>Odstup řádků</translation>
    </message>
    <message>
        <source>Page skin</source>
        <translation>Vzhled strany</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Vzorek</translation>
    </message>
    <message>
        <source>.TXT files</source>
        <translation>Soubory .TXT</translation>
    </message>
    <message>
        <source>Disable automatic formatting</source>
        <translation>Zakázat automatické formátování</translation>
    </message>
    <message>
        <source>Styles</source>
        <translation>Styly</translation>
    </message>
    <message>
        <source>Selection color</source>
        <translation>Barva výběru</translation>
    </message>
    <message>
        <source>Comment color</source>
        <translation>Barva poznámky</translation>
    </message>
    <message>
        <source>Correction color</source>
        <translation>Barva opravy</translation>
    </message>
    <message>
        <source>Bookmark highlight</source>
        <translation>Zvýraznění záložky</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázáno</translation>
    </message>
    <message>
        <source>Solid fill</source>
        <translation>Plná výplň</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podtržení</translation>
    </message>
    <message>
        <source>Inline images zoom in</source>
        <translation>Přiblížení vložených obrázků</translation>
    </message>
    <message>
        <source>Integer scale</source>
        <translation>Celočíselný násobek</translation>
    </message>
    <message>
        <source>Arbitrary scale</source>
        <translation>Libovolné měřítko</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>Block images zoom in</source>
        <translation>Přiblížení obyčejných obrázků</translation>
    </message>
    <message>
        <source>Block images zoom out</source>
        <translation>Oddálení obyčejných obrázků</translation>
    </message>
    <message>
        <source>Inline images zoom out</source>
        <translation>Oddálení vložených obrázků</translation>
    </message>
    <message>
        <source>Image scaling options</source>
        <translation>Volby pro změnu velikosti obrázků</translation>
    </message>
    <message>
        <source>Floating punctuation</source>
        <translation>Volná interpunkce</translation>
    </message>
    <message>
        <source>Enable floating punctuation</source>
        <translation>Povolit volnou interpunkci</translation>
    </message>
    <message>
        <source>0.3</source>
        <translation>0.3</translation>
    </message>
    <message>
        <source>0.35</source>
        <translation>0.35</translation>
    </message>
    <message>
        <source>0.4</source>
        <translation>0.4</translation>
    </message>
    <message>
        <source>0.45</source>
        <translation>0.45</translation>
    </message>
    <message>
        <source>0.5</source>
        <translation>0.5</translation>
    </message>
    <message>
        <source>0.55</source>
        <translation>0.55</translation>
    </message>
    <message>
        <source>0.6</source>
        <translation>0.6</translation>
    </message>
    <message>
        <source>0.65</source>
        <translation>0.65</translation>
    </message>
    <message>
        <source>0.7</source>
        <translation>0.7</translation>
    </message>
    <message>
        <source>0.75</source>
        <translation>0.75</translation>
    </message>
    <message>
        <source>0.8</source>
        <translation>0.8</translation>
    </message>
    <message>
        <source>0.85</source>
        <translation>0.85</translation>
    </message>
    <message>
        <source>0.9</source>
        <translation>0.9</translation>
    </message>
    <message>
        <source>0.95</source>
        <translation>0.95</translation>
    </message>
    <message>
        <source>0.98</source>
        <translation>0.98</translation>
    </message>
    <message>
        <source>1.0</source>
        <translation>1.0</translation>
    </message>
    <message>
        <source>1.02</source>
        <translation>1.02</translation>
    </message>
    <message>
        <source>1.05</source>
        <translation>1.05</translation>
    </message>
    <message>
        <source>1.1</source>
        <translation>1.1</translation>
    </message>
    <message>
        <source>1.15</source>
        <translation>1.15</translation>
    </message>
    <message>
        <source>1.2</source>
        <translation>1.2</translation>
    </message>
    <message>
        <source>1.25</source>
        <translation>1.25</translation>
    </message>
    <message>
        <source>1.3</source>
        <translation>1.3</translation>
    </message>
    <message>
        <source>1.35</source>
        <translation>1.35</translation>
    </message>
    <message>
        <source>1.4</source>
        <translation>1.4</translation>
    </message>
    <message>
        <source>1.45</source>
        <translation>1.45</translation>
    </message>
    <message>
        <source>1.5</source>
        <translation>1.5</translation>
    </message>
    <message>
        <source>1.6</source>
        <translation>1.6</translation>
    </message>
    <message>
        <source>1.7</source>
        <translation>1.7</translation>
    </message>
    <message>
        <source>1.8</source>
        <translation>1.8</translation>
    </message>
    <message>
        <source>1.9</source>
        <translation>1.9</translation>
    </message>
    <message>
        <source>Font Gamma</source>
        <translation>Gamma písma</translation>
    </message>
    <message>
        <source>Font hinting</source>
        <translation>Instruování písma</translation>
    </message>
    <message>
        <source>No hinting</source>
        <translation>Bez instruování písma</translation>
    </message>
    <message>
        <source>Use bytecode</source>
        <translation>Použít bytecode</translation>
    </message>
    <message>
        <source>Autohinting</source>
        <translation>Automatické instruování písma</translation>
    </message>
    <message>
        <source>Fallback fonts</source>
        <translation>Záložní písma</translation>
    </message>
    <message>
        <source>Enable document internal styles</source>
        <translation>Povolit v dokumentu vnitřní styly</translation>
    </message>
    <message>
        <source>Internal CSS</source>
        <translation>Vnitřní CSS</translation>
    </message>
    <message>
        <source>Enable document embedded fonts</source>
        <translation>Povolit písma vložená do dokumentu</translation>
    </message>
    <message>
        <source>.EPUB</source>
        <translation>Soubory .EPUB</translation>
    </message>
    <message>
        <source>Stylesheet</source>
        <translation>Stylový list</translation>
    </message>
    <message>
        <source>Default paragraph style</source>
        <translation>Styl výchozího odstavce</translation>
    </message>
    <message>
        <source>Alignment</source>
        <translation>Zarovnání</translation>
    </message>
    <message>
        <source>First line</source>
        <translation>První řádek</translation>
    </message>
    <message>
        <source>Font size</source>
        <translation>Velikost písma</translation>
    </message>
    <message>
        <source>Font face</source>
        <translation>Druh písma</translation>
    </message>
    <message>
        <source>Font weight</source>
        <translation>Váha písma</translation>
    </message>
    <message>
        <source>Font style</source>
        <translation>Styl písma</translation>
    </message>
    <message>
        <source>Font color</source>
        <translation>Barva písma</translation>
    </message>
    <message>
        <source>Margins:</source>
        <translation>Okraje:</translation>
    </message>
    <message>
        <source>Before</source>
        <translation>Před</translation>
    </message>
    <message>
        <source>After</source>
        <translation>Po</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Interline space</source>
        <translation>Mezera mezi řádky</translation>
    </message>
    <message>
        <source>Text decoration</source>
        <translation>Zdobení textu</translation>
    </message>
    <message>
        <source>Vertical align</source>
        <translation>Svislé zarovnání</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Podnázev</translation>
    </message>
    <message>
        <source>Preformatted text</source>
        <translation>Předformátovaný text</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Odkaz</translation>
    </message>
    <message>
        <source>Cite / quotation</source>
        <translation>Citace</translation>
    </message>
    <message>
        <source>Epigraph</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Poem</source>
        <translation>Báseň</translation>
    </message>
    <message>
        <source>Text author</source>
        <translation>Autor textu</translation>
    </message>
    <message>
        <source>Footnote link</source>
        <translation>Odkaz na poznámku pod čarou</translation>
    </message>
    <message>
        <source>Footnote</source>
        <translation>Poznámka pod čarou</translation>
    </message>
    <message>
        <source>Footnote title</source>
        <translation>Název poznámky pod čarou</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>Vysvětlivka</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Justify</source>
        <translation>Zarovnat do bloku</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Zarovnat na střed</translation>
    </message>
    <message>
        <source>No indent</source>
        <translation>Bez odsazení</translation>
    </message>
    <message>
        <source>Small Indent</source>
        <translation>Malé odsazení</translation>
    </message>
    <message>
        <source>Big Indent</source>
        <translation>Velké odsazení</translation>
    </message>
    <message>
        <source>Small Outdent</source>
        <translation>Malé předsazení</translation>
    </message>
    <message>
        <source>Big Outdent</source>
        <translation>Velké předsazení</translation>
    </message>
    <message>
        <source>20% of line height</source>
        <translation>20 % výšky řádku</translation>
    </message>
    <message>
        <source>30% of line height</source>
        <translation>30 % výšky řádku</translation>
    </message>
    <message>
        <source>50% of line height</source>
        <translation>50 % výšky řádku</translation>
    </message>
    <message>
        <source>100% of line height</source>
        <translation>100 % výšky řádku</translation>
    </message>
    <message>
        <source>150% of line height</source>
        <translation>150 % výšky řádku</translation>
    </message>
    <message>
        <source>200% of line height</source>
        <translation>200 % výšky řádku</translation>
    </message>
    <message>
        <source>400% of line height</source>
        <translation>400 % výšky řádku</translation>
    </message>
    <message>
        <source>5% of line width</source>
        <translation>5 % šířky řádku</translation>
    </message>
    <message>
        <source>10% of line width</source>
        <translation>10 % šířky řádku</translation>
    </message>
    <message>
        <source>15% of line width</source>
        <translation>15 % šířky řádku</translation>
    </message>
    <message>
        <source>20% of line width</source>
        <translation>20 % šířky řádku</translation>
    </message>
    <message>
        <source>30% of line width</source>
        <translation>30 % šířky řádku</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Obvyklé</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <source>Bolder</source>
        <translation>Tučnější</translation>
    </message>
    <message>
        <source>Lighter</source>
        <translation>Lehčí</translation>
    </message>
    <message>
        <source>Increase: 110%</source>
        <translation>Zvětšit: 110 %</translation>
    </message>
    <message>
        <source>Increase: 120%</source>
        <translation>Zvětšit: 120 %</translation>
    </message>
    <message>
        <source>Increase: 150%</source>
        <translation>Zvětšit: 150 %</translation>
    </message>
    <message>
        <source>Decrease: 90%</source>
        <translation>Zmenšit: 90 %</translation>
    </message>
    <message>
        <source>Decrease: 80%</source>
        <translation>Zmenšit: 80 %</translation>
    </message>
    <message>
        <source>Decrease: 70%</source>
        <translation>Zmenšit: 70 %</translation>
    </message>
    <message>
        <source>Decrease: 60%</source>
        <translation>Zmenšit: 60 %</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
    <message>
        <source>[Default Sans Serif]</source>
        <translation>[Výchozí bezpatkové]</translation>
    </message>
    <message>
        <source>[Default Serif]</source>
        <translation>[Výchozí patkové]</translation>
    </message>
    <message>
        <source>[Default Monospace]</source>
        <translation>[Výchozí strojové s pevnou šířkou]</translation>
    </message>
    <message>
        <source>Black</source>
        <translation>Černá</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Zelená</translation>
    </message>
    <message>
        <source>Silver</source>
        <translation>Stříbrná</translation>
    </message>
    <message>
        <source>Lime</source>
        <translation>Světle zelená</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Šedá</translation>
    </message>
    <message>
        <source>Olive</source>
        <translation>Olivově zelená</translation>
    </message>
    <message>
        <source>White</source>
        <translation>Bílá</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Žlutá</translation>
    </message>
    <message>
        <source>Maroon</source>
        <translation>Kaštanově hnědá</translation>
    </message>
    <message>
        <source>Navy</source>
        <translation>Tmavomodrá</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Červená</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Modrá</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Purpurová</translation>
    </message>
    <message>
        <source>Teal</source>
        <translation>Tmavě modrozelená</translation>
    </message>
    <message>
        <source>Fuchsia</source>
        <translation>Červenofialová barva</translation>
    </message>
    <message>
        <source>Aqua</source>
        <translation>Modrozelená</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Line through</source>
        <translation>Přeškrtnutí</translation>
    </message>
    <message>
        <source>Overline</source>
        <translation>Nadtržení</translation>
    </message>
    <message>
        <source>Baseline</source>
        <translation>Základní čára</translation>
    </message>
    <message>
        <source>Subscript</source>
        <translation>Dolní index</translation>
    </message>
    <message>
        <source>Superscript</source>
        <translation>Horní index</translation>
    </message>
    <message>
        <source>Comment bookmark color</source>
        <translation>Barva záložky poznámky</translation>
    </message>
    <message>
        <source>Correction bookmark color</source>
        <translation>Barva záložky opravy</translation>
    </message>
    <message>
        <source>4</source>
        <translation type="unfinished">4</translation>
    </message>
    <message>
        <source>6</source>
        <translation type="unfinished">6</translation>
    </message>
    <message>
        <source>7</source>
        <translation type="unfinished">7</translation>
    </message>
    <message>
        <source>9</source>
        <translation type="unfinished">9</translation>
    </message>
    <message>
        <source>11</source>
        <translation type="unfinished">11</translation>
    </message>
    <message>
        <source>12</source>
        <translation type="unfinished">12</translation>
    </message>
    <message>
        <source>40</source>
        <translation type="unfinished">40</translation>
    </message>
    <message>
        <source>50</source>
        <translation type="unfinished">50</translation>
    </message>
    <message>
        <source>60</source>
        <translation type="unfinished">60</translation>
    </message>
    <message>
        <source>Font kerning</source>
        <translation>Kerning písma</translation>
    </message>
    <message>
        <source>Enable font kerning</source>
        <translation type="unfinished">Povolit kerning písma</translation>
    </message>
</context>
<context>
    <name>TocDlg</name>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Strana</translation>
    </message>
    <message>
        <source>Table of Contents</source>
        <translation>Obsah</translation>
    </message>
</context>
<context>
    <name>WolExportDlg</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Bits per pixel</source>
        <translation>Bitů na pixel</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>Table of Contents levels</source>
        <translation>Úrovně obsahu</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
</context>
</TS>
